
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef __LIBQMI_GLIB_ENUM_TYPES_H__
#define __LIBQMI_GLIB_ENUM_TYPES_H__
#include "qmi-enums.h"
#include "qmi-enums-wds.h"
#include "qmi-enums-dms.h"
#include "qmi-enums-nas.h"
#include "qmi-enums-wms.h"
#include "qmi-enums-pds.h"
#include "qmi-enums-pdc.h"
#include "qmi-enums-pbm.h"
#include "qmi-enums-uim.h"
#include "qmi-enums-sar.h"
#include "qmi-enums-oma.h"
#include "qmi-enums-wda.h"
#include "qmi-enums-voice.h"
#include "qmi-enums-loc.h"
#include "qmi-enums-qos.h"
#include "qmi-enums-gas.h"
#include "qmi-enums-dsd.h"
#include "qmi-enums-fox.h"
#include "qmi-enums-imsp.h"
#include "qmi-enums-imsa.h"
#include "qmi-enums-ssc.h"
#include "qmi-device.h"

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "../git/src/libqmi-glib/qmi-device.h" */
GType qmi_device_expected_data_format_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DEVICE_EXPECTED_DATA_FORMAT (qmi_device_expected_data_format_get_type ())

/* Define type-specific symbols */
#define __QMI_DEVICE_EXPECTED_DATA_FORMAT_IS_ENUM__

/**
 * qmi_device_expected_data_format_get_string:
 * @val: a QmiDeviceExpectedDataFormat.
 *
 * Gets the nickname string for the #QmiDeviceExpectedDataFormat specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_device_expected_data_format_get_string (QmiDeviceExpectedDataFormat val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-dms.h" */
GType qmi_dms_data_service_capability_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_DATA_SERVICE_CAPABILITY (qmi_dms_data_service_capability_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_DATA_SERVICE_CAPABILITY_IS_ENUM__

/**
 * qmi_dms_data_service_capability_get_string:
 * @val: a QmiDmsDataServiceCapability.
 *
 * Gets the nickname string for the #QmiDmsDataServiceCapability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_data_service_capability_get_string (QmiDmsDataServiceCapability val);
GType qmi_dms_sim_capability_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_SIM_CAPABILITY (qmi_dms_sim_capability_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_SIM_CAPABILITY_IS_ENUM__

/**
 * qmi_dms_sim_capability_get_string:
 * @val: a QmiDmsSimCapability.
 *
 * Gets the nickname string for the #QmiDmsSimCapability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_sim_capability_get_string (QmiDmsSimCapability val);
GType qmi_dms_radio_interface_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_RADIO_INTERFACE (qmi_dms_radio_interface_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_RADIO_INTERFACE_IS_ENUM__

/**
 * qmi_dms_radio_interface_get_string:
 * @val: a QmiDmsRadioInterface.
 *
 * Gets the nickname string for the #QmiDmsRadioInterface specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_radio_interface_get_string (QmiDmsRadioInterface val);
GType qmi_dms_uim_pin_id_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_UIM_PIN_ID (qmi_dms_uim_pin_id_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_UIM_PIN_ID_IS_ENUM__

/**
 * qmi_dms_uim_pin_id_get_string:
 * @val: a QmiDmsUimPinId.
 *
 * Gets the nickname string for the #QmiDmsUimPinId specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_uim_pin_id_get_string (QmiDmsUimPinId val);
GType qmi_dms_uim_pin_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_UIM_PIN_STATUS (qmi_dms_uim_pin_status_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_UIM_PIN_STATUS_IS_ENUM__

/**
 * qmi_dms_uim_pin_status_get_string:
 * @val: a QmiDmsUimPinStatus.
 *
 * Gets the nickname string for the #QmiDmsUimPinStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_uim_pin_status_get_string (QmiDmsUimPinStatus val);
GType qmi_dms_operating_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_OPERATING_MODE (qmi_dms_operating_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_OPERATING_MODE_IS_ENUM__

/**
 * qmi_dms_operating_mode_get_string:
 * @val: a QmiDmsOperatingMode.
 *
 * Gets the nickname string for the #QmiDmsOperatingMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_operating_mode_get_string (QmiDmsOperatingMode val);
GType qmi_dms_time_source_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_TIME_SOURCE (qmi_dms_time_source_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_TIME_SOURCE_IS_ENUM__

/**
 * qmi_dms_time_source_get_string:
 * @val: a QmiDmsTimeSource.
 *
 * Gets the nickname string for the #QmiDmsTimeSource specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_time_source_get_string (QmiDmsTimeSource val);
GType qmi_dms_activation_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_ACTIVATION_STATE (qmi_dms_activation_state_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_ACTIVATION_STATE_IS_ENUM__

/**
 * qmi_dms_activation_state_get_string:
 * @val: a QmiDmsActivationState.
 *
 * Gets the nickname string for the #QmiDmsActivationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_activation_state_get_string (QmiDmsActivationState val);
GType qmi_dms_uim_facility_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_UIM_FACILITY (qmi_dms_uim_facility_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_UIM_FACILITY_IS_ENUM__

/**
 * qmi_dms_uim_facility_get_string:
 * @val: a QmiDmsUimFacility.
 *
 * Gets the nickname string for the #QmiDmsUimFacility specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_uim_facility_get_string (QmiDmsUimFacility val);
GType qmi_dms_uim_facility_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_UIM_FACILITY_STATE (qmi_dms_uim_facility_state_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_UIM_FACILITY_STATE_IS_ENUM__

/**
 * qmi_dms_uim_facility_state_get_string:
 * @val: a QmiDmsUimFacilityState.
 *
 * Gets the nickname string for the #QmiDmsUimFacilityState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_uim_facility_state_get_string (QmiDmsUimFacilityState val);
GType qmi_dms_uim_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_UIM_STATE (qmi_dms_uim_state_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_UIM_STATE_IS_ENUM__

/**
 * qmi_dms_uim_state_get_string:
 * @val: a QmiDmsUimState.
 *
 * Gets the nickname string for the #QmiDmsUimState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_uim_state_get_string (QmiDmsUimState val);
GType qmi_dms_time_reference_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_TIME_REFERENCE_TYPE (qmi_dms_time_reference_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_TIME_REFERENCE_TYPE_IS_ENUM__

/**
 * qmi_dms_time_reference_type_get_string:
 * @val: a QmiDmsTimeReferenceType.
 *
 * Gets the nickname string for the #QmiDmsTimeReferenceType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_time_reference_type_get_string (QmiDmsTimeReferenceType val);
GType qmi_dms_firmware_image_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_FIRMWARE_IMAGE_TYPE (qmi_dms_firmware_image_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_FIRMWARE_IMAGE_TYPE_IS_ENUM__

/**
 * qmi_dms_firmware_image_type_get_string:
 * @val: a QmiDmsFirmwareImageType.
 *
 * Gets the nickname string for the #QmiDmsFirmwareImageType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_dms_firmware_image_type_get_string (QmiDmsFirmwareImageType val);
GType qmi_dms_boot_image_download_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_BOOT_IMAGE_DOWNLOAD_MODE (qmi_dms_boot_image_download_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_BOOT_IMAGE_DOWNLOAD_MODE_IS_ENUM__

/**
 * qmi_dms_boot_image_download_mode_get_string:
 * @val: a QmiDmsBootImageDownloadMode.
 *
 * Gets the nickname string for the #QmiDmsBootImageDownloadMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_dms_boot_image_download_mode_get_string (QmiDmsBootImageDownloadMode val);
GType qmi_dms_mac_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_MAC_TYPE (qmi_dms_mac_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_MAC_TYPE_IS_ENUM__

/**
 * qmi_dms_mac_type_get_string:
 * @val: a QmiDmsMacType.
 *
 * Gets the nickname string for the #QmiDmsMacType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_dms_mac_type_get_string (QmiDmsMacType val);
GType qmi_dms_hp_device_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_HP_DEVICE_MODE (qmi_dms_hp_device_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_HP_DEVICE_MODE_IS_ENUM__

/**
 * qmi_dms_hp_device_mode_get_string:
 * @val: a QmiDmsHpDeviceMode.
 *
 * Gets the nickname string for the #QmiDmsHpDeviceMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_dms_hp_device_mode_get_string (QmiDmsHpDeviceMode val);
GType qmi_dms_swi_usb_composition_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_SWI_USB_COMPOSITION (qmi_dms_swi_usb_composition_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_SWI_USB_COMPOSITION_IS_ENUM__

/**
 * qmi_dms_swi_usb_composition_get_string:
 * @val: a QmiDmsSwiUsbComposition.
 *
 * Gets the nickname string for the #QmiDmsSwiUsbComposition specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.20
 */
const gchar *qmi_dms_swi_usb_composition_get_string (QmiDmsSwiUsbComposition val);
GType qmi_dms_foxconn_device_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_FOXCONN_DEVICE_MODE (qmi_dms_foxconn_device_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_FOXCONN_DEVICE_MODE_IS_ENUM__

/**
 * qmi_dms_foxconn_device_mode_get_string:
 * @val: a QmiDmsFoxconnDeviceMode.
 *
 * Gets the nickname string for the #QmiDmsFoxconnDeviceMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_dms_foxconn_device_mode_get_string (QmiDmsFoxconnDeviceMode val);
GType qmi_dms_foxconn_firmware_version_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DMS_FOXCONN_FIRMWARE_VERSION_TYPE (qmi_dms_foxconn_firmware_version_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_IS_ENUM__

/**
 * qmi_dms_foxconn_firmware_version_type_get_string:
 * @val: a QmiDmsFoxconnFirmwareVersionType.
 *
 * Gets the nickname string for the #QmiDmsFoxconnFirmwareVersionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_dms_foxconn_firmware_version_type_get_string (QmiDmsFoxconnFirmwareVersionType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-dsd.h" */
GType qmi_dsd_apn_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DSD_APN_TYPE (qmi_dsd_apn_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DSD_APN_TYPE_IS_ENUM__

/**
 * qmi_dsd_apn_type_get_string:
 * @val: a QmiDsdApnType.
 *
 * Gets the nickname string for the #QmiDsdApnType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_dsd_apn_type_get_string (QmiDsdApnType val);
GType qmi_dsd_data_system_network_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DSD_DATA_SYSTEM_NETWORK_TYPE (qmi_dsd_data_system_network_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DSD_DATA_SYSTEM_NETWORK_TYPE_IS_ENUM__

/**
 * qmi_dsd_data_system_network_type_get_string:
 * @val: a QmiDsdDataSystemNetworkType.
 *
 * Gets the nickname string for the #QmiDsdDataSystemNetworkType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.32
 */
const gchar *qmi_dsd_data_system_network_type_get_string (QmiDsdDataSystemNetworkType val);
GType qmi_dsd_radio_access_technology_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DSD_RADIO_ACCESS_TECHNOLOGY (qmi_dsd_radio_access_technology_get_type ())

/* Define type-specific symbols */
#define __QMI_DSD_RADIO_ACCESS_TECHNOLOGY_IS_ENUM__

/**
 * qmi_dsd_radio_access_technology_get_string:
 * @val: a QmiDsdRadioAccessTechnology.
 *
 * Gets the nickname string for the #QmiDsdRadioAccessTechnology specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.32
 */
const gchar *qmi_dsd_radio_access_technology_get_string (QmiDsdRadioAccessTechnology val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-fox.h" */
GType qmi_fox_firmware_version_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_FOX_FIRMWARE_VERSION_TYPE (qmi_fox_firmware_version_type_get_type ())

/* Define type-specific symbols */
#define __QMI_FOX_FIRMWARE_VERSION_TYPE_IS_ENUM__

/**
 * qmi_fox_firmware_version_type_get_string:
 * @val: a QmiFoxFirmwareVersionType.
 *
 * Gets the nickname string for the #QmiFoxFirmwareVersionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.32
 */
const gchar *qmi_fox_firmware_version_type_get_string (QmiFoxFirmwareVersionType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-gas.h" */
GType qmi_gas_firmware_listing_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_GAS_FIRMWARE_LISTING_MODE (qmi_gas_firmware_listing_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_GAS_FIRMWARE_LISTING_MODE_IS_ENUM__

/**
 * qmi_gas_firmware_listing_mode_get_string:
 * @val: a QmiGasFirmwareListingMode.
 *
 * Gets the nickname string for the #QmiGasFirmwareListingMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_gas_firmware_listing_mode_get_string (QmiGasFirmwareListingMode val);
GType qmi_gas_usb_composition_endpoint_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_GAS_USB_COMPOSITION_ENDPOINT_TYPE (qmi_gas_usb_composition_endpoint_type_get_type ())

/* Define type-specific symbols */
#define __QMI_GAS_USB_COMPOSITION_ENDPOINT_TYPE_IS_ENUM__

/**
 * qmi_gas_usb_composition_endpoint_type_get_string:
 * @val: a QmiGasUsbCompositionEndpointType.
 *
 * Gets the nickname string for the #QmiGasUsbCompositionEndpointType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.32
 */
const gchar *qmi_gas_usb_composition_endpoint_type_get_string (QmiGasUsbCompositionEndpointType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-imsa.h" */
GType qmi_imsa_ims_registration_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_IMSA_IMS_REGISTRATION_STATUS (qmi_imsa_ims_registration_status_get_type ())

/* Define type-specific symbols */
#define __QMI_IMSA_IMS_REGISTRATION_STATUS_IS_ENUM__

/**
 * qmi_imsa_ims_registration_status_get_string:
 * @val: a QmiImsaImsRegistrationStatus.
 *
 * Gets the nickname string for the #QmiImsaImsRegistrationStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_imsa_ims_registration_status_get_string (QmiImsaImsRegistrationStatus val);
GType qmi_imsa_service_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_IMSA_SERVICE_STATUS (qmi_imsa_service_status_get_type ())

/* Define type-specific symbols */
#define __QMI_IMSA_SERVICE_STATUS_IS_ENUM__

/**
 * qmi_imsa_service_status_get_string:
 * @val: a QmiImsaServiceStatus.
 *
 * Gets the nickname string for the #QmiImsaServiceStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_imsa_service_status_get_string (QmiImsaServiceStatus val);
GType qmi_imsa_registration_technology_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_IMSA_REGISTRATION_TECHNOLOGY (qmi_imsa_registration_technology_get_type ())

/* Define type-specific symbols */
#define __QMI_IMSA_REGISTRATION_TECHNOLOGY_IS_ENUM__

/**
 * qmi_imsa_registration_technology_get_string:
 * @val: a QmiImsaRegistrationTechnology.
 *
 * Gets the nickname string for the #QmiImsaRegistrationTechnology specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_imsa_registration_technology_get_string (QmiImsaRegistrationTechnology val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-imsp.h" */
GType qmi_imsp_enabler_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_IMSP_ENABLER_STATE (qmi_imsp_enabler_state_get_type ())

/* Define type-specific symbols */
#define __QMI_IMSP_ENABLER_STATE_IS_ENUM__

/**
 * qmi_imsp_enabler_state_get_string:
 * @val: a QmiImspEnablerState.
 *
 * Gets the nickname string for the #QmiImspEnablerState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_imsp_enabler_state_get_string (QmiImspEnablerState val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-loc.h" */
GType qmi_loc_intermediate_report_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_INTERMEDIATE_REPORT_STATE (qmi_loc_intermediate_report_state_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_INTERMEDIATE_REPORT_STATE_IS_ENUM__

/**
 * qmi_loc_intermediate_report_state_get_string:
 * @val: a QmiLocIntermediateReportState.
 *
 * Gets the nickname string for the #QmiLocIntermediateReportState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.20
 */
const gchar *qmi_loc_intermediate_report_state_get_string (QmiLocIntermediateReportState val);
GType qmi_loc_indication_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_INDICATION_STATUS (qmi_loc_indication_status_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_INDICATION_STATUS_IS_ENUM__

/**
 * qmi_loc_indication_status_get_string:
 * @val: a QmiLocIndicationStatus.
 *
 * Gets the nickname string for the #QmiLocIndicationStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_indication_status_get_string (QmiLocIndicationStatus val);
GType qmi_loc_session_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_SESSION_STATUS (qmi_loc_session_status_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_SESSION_STATUS_IS_ENUM__

/**
 * qmi_loc_session_status_get_string:
 * @val: a QmiLocSessionStatus.
 *
 * Gets the nickname string for the #QmiLocSessionStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_session_status_get_string (QmiLocSessionStatus val);
GType qmi_loc_fix_recurrence_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_FIX_RECURRENCE_TYPE (qmi_loc_fix_recurrence_type_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_FIX_RECURRENCE_TYPE_IS_ENUM__

/**
 * qmi_loc_fix_recurrence_type_get_string:
 * @val: a QmiLocFixRecurrenceType.
 *
 * Gets the nickname string for the #QmiLocFixRecurrenceType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_fix_recurrence_type_get_string (QmiLocFixRecurrenceType val);
GType qmi_loc_operation_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_OPERATION_MODE (qmi_loc_operation_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_OPERATION_MODE_IS_ENUM__

/**
 * qmi_loc_operation_mode_get_string:
 * @val: a QmiLocOperationMode.
 *
 * Gets the nickname string for the #QmiLocOperationMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_operation_mode_get_string (QmiLocOperationMode val);
GType qmi_loc_engine_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_ENGINE_STATE (qmi_loc_engine_state_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_ENGINE_STATE_IS_ENUM__

/**
 * qmi_loc_engine_state_get_string:
 * @val: a QmiLocEngineState.
 *
 * Gets the nickname string for the #QmiLocEngineState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_engine_state_get_string (QmiLocEngineState val);
GType qmi_loc_reliability_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_RELIABILITY (qmi_loc_reliability_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_RELIABILITY_IS_ENUM__

/**
 * qmi_loc_reliability_get_string:
 * @val: a QmiLocReliability.
 *
 * Gets the nickname string for the #QmiLocReliability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_reliability_get_string (QmiLocReliability val);
GType qmi_loc_time_source_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_TIME_SOURCE (qmi_loc_time_source_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_TIME_SOURCE_IS_ENUM__

/**
 * qmi_loc_time_source_get_string:
 * @val: a QmiLocTimeSource.
 *
 * Gets the nickname string for the #QmiLocTimeSource specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_time_source_get_string (QmiLocTimeSource val);
GType qmi_loc_system_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_SYSTEM (qmi_loc_system_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_SYSTEM_IS_ENUM__

/**
 * qmi_loc_system_get_string:
 * @val: a QmiLocSystem.
 *
 * Gets the nickname string for the #QmiLocSystem specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_system_get_string (QmiLocSystem val);
GType qmi_loc_health_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_HEALTH_STATUS (qmi_loc_health_status_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_HEALTH_STATUS_IS_ENUM__

/**
 * qmi_loc_health_status_get_string:
 * @val: a QmiLocHealthStatus.
 *
 * Gets the nickname string for the #QmiLocHealthStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_health_status_get_string (QmiLocHealthStatus val);
GType qmi_loc_navigation_data_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_NAVIGATION_DATA (qmi_loc_navigation_data_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_NAVIGATION_DATA_IS_ENUM__

/**
 * qmi_loc_navigation_data_get_string:
 * @val: a QmiLocNavigationData.
 *
 * Gets the nickname string for the #QmiLocNavigationData specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_navigation_data_get_string (QmiLocNavigationData val);
GType qmi_loc_satellite_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_SATELLITE_STATUS (qmi_loc_satellite_status_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_SATELLITE_STATUS_IS_ENUM__

/**
 * qmi_loc_satellite_status_get_string:
 * @val: a QmiLocSatelliteStatus.
 *
 * Gets the nickname string for the #QmiLocSatelliteStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_satellite_status_get_string (QmiLocSatelliteStatus val);
GType qmi_loc_server_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_SERVER_TYPE (qmi_loc_server_type_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_SERVER_TYPE_IS_ENUM__

/**
 * qmi_loc_server_type_get_string:
 * @val: a QmiLocServerType.
 *
 * Gets the nickname string for the #QmiLocServerType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_server_type_get_string (QmiLocServerType val);
GType qmi_loc_predicted_orbits_data_format_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_PREDICTED_ORBITS_DATA_FORMAT (qmi_loc_predicted_orbits_data_format_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_PREDICTED_ORBITS_DATA_FORMAT_IS_ENUM__

/**
 * qmi_loc_predicted_orbits_data_format_get_string:
 * @val: a QmiLocPredictedOrbitsDataFormat.
 *
 * Gets the nickname string for the #QmiLocPredictedOrbitsDataFormat specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_loc_predicted_orbits_data_format_get_string (QmiLocPredictedOrbitsDataFormat val);
GType qmi_loc_lock_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_LOC_LOCK_TYPE (qmi_loc_lock_type_get_type ())

/* Define type-specific symbols */
#define __QMI_LOC_LOCK_TYPE_IS_ENUM__

/**
 * qmi_loc_lock_type_get_string:
 * @val: a QmiLocLockType.
 *
 * Gets the nickname string for the #QmiLocLockType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_loc_lock_type_get_string (QmiLocLockType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-nas.h" */
GType qmi_nas_radio_interface_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_RADIO_INTERFACE (qmi_nas_radio_interface_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_RADIO_INTERFACE_IS_ENUM__

/**
 * qmi_nas_radio_interface_get_string:
 * @val: a QmiNasRadioInterface.
 *
 * Gets the nickname string for the #QmiNasRadioInterface specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_radio_interface_get_string (QmiNasRadioInterface val);
GType qmi_nas_active_band_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_ACTIVE_BAND (qmi_nas_active_band_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_ACTIVE_BAND_IS_ENUM__

/**
 * qmi_nas_active_band_get_string:
 * @val: a QmiNasActiveBand.
 *
 * Gets the nickname string for the #QmiNasActiveBand specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_active_band_get_string (QmiNasActiveBand val);
GType qmi_nas_network_service_domain_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_SERVICE_DOMAIN (qmi_nas_network_service_domain_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_SERVICE_DOMAIN_IS_ENUM__

/**
 * qmi_nas_network_service_domain_get_string:
 * @val: a QmiNasNetworkServiceDomain.
 *
 * Gets the nickname string for the #QmiNasNetworkServiceDomain specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_network_service_domain_get_string (QmiNasNetworkServiceDomain val);
GType qmi_nas_evdo_sinr_level_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_EVDO_SINR_LEVEL (qmi_nas_evdo_sinr_level_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_EVDO_SINR_LEVEL_IS_ENUM__

/**
 * qmi_nas_evdo_sinr_level_get_string:
 * @val: a QmiNasEvdoSinrLevel.
 *
 * Gets the nickname string for the #QmiNasEvdoSinrLevel specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_evdo_sinr_level_get_string (QmiNasEvdoSinrLevel val);
GType qmi_nas_network_scan_result_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_SCAN_RESULT (qmi_nas_network_scan_result_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_SCAN_RESULT_IS_ENUM__

/**
 * qmi_nas_network_scan_result_get_string:
 * @val: a QmiNasNetworkScanResult.
 *
 * Gets the nickname string for the #QmiNasNetworkScanResult specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_network_scan_result_get_string (QmiNasNetworkScanResult val);
GType qmi_nas_network_register_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_REGISTER_TYPE (qmi_nas_network_register_type_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_REGISTER_TYPE_IS_ENUM__

/**
 * qmi_nas_network_register_type_get_string:
 * @val: a QmiNasNetworkRegisterType.
 *
 * Gets the nickname string for the #QmiNasNetworkRegisterType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_network_register_type_get_string (QmiNasNetworkRegisterType val);
GType qmi_nas_ps_attach_action_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_PS_ATTACH_ACTION (qmi_nas_ps_attach_action_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_PS_ATTACH_ACTION_IS_ENUM__

/**
 * qmi_nas_ps_attach_action_get_string:
 * @val: a QmiNasPsAttachAction.
 *
 * Gets the nickname string for the #QmiNasPsAttachAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.20
 */
const gchar *qmi_nas_ps_attach_action_get_string (QmiNasPsAttachAction val);
GType qmi_nas_registration_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_REGISTRATION_STATE (qmi_nas_registration_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_REGISTRATION_STATE_IS_ENUM__

/**
 * qmi_nas_registration_state_get_string:
 * @val: a QmiNasRegistrationState.
 *
 * Gets the nickname string for the #QmiNasRegistrationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_registration_state_get_string (QmiNasRegistrationState val);
GType qmi_nas_attach_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_ATTACH_STATE (qmi_nas_attach_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_ATTACH_STATE_IS_ENUM__

/**
 * qmi_nas_attach_state_get_string:
 * @val: a QmiNasAttachState.
 *
 * Gets the nickname string for the #QmiNasAttachState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_attach_state_get_string (QmiNasAttachState val);
GType qmi_nas_network_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_TYPE (qmi_nas_network_type_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_TYPE_IS_ENUM__

/**
 * qmi_nas_network_type_get_string:
 * @val: a QmiNasNetworkType.
 *
 * Gets the nickname string for the #QmiNasNetworkType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_network_type_get_string (QmiNasNetworkType val);
GType qmi_nas_roaming_indicator_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_ROAMING_INDICATOR_STATUS (qmi_nas_roaming_indicator_status_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_ROAMING_INDICATOR_STATUS_IS_ENUM__

/**
 * qmi_nas_roaming_indicator_status_get_string:
 * @val: a QmiNasRoamingIndicatorStatus.
 *
 * Gets the nickname string for the #QmiNasRoamingIndicatorStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_roaming_indicator_status_get_string (QmiNasRoamingIndicatorStatus val);
GType qmi_nas_data_capability_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_DATA_CAPABILITY (qmi_nas_data_capability_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_DATA_CAPABILITY_IS_ENUM__

/**
 * qmi_nas_data_capability_get_string:
 * @val: a QmiNasDataCapability.
 *
 * Gets the nickname string for the #QmiNasDataCapability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_data_capability_get_string (QmiNasDataCapability val);
GType qmi_nas_service_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SERVICE_STATUS (qmi_nas_service_status_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SERVICE_STATUS_IS_ENUM__

/**
 * qmi_nas_service_status_get_string:
 * @val: a QmiNasServiceStatus.
 *
 * Gets the nickname string for the #QmiNasServiceStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_service_status_get_string (QmiNasServiceStatus val);
GType qmi_nas_hdr_personality_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_HDR_PERSONALITY (qmi_nas_hdr_personality_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_HDR_PERSONALITY_IS_ENUM__

/**
 * qmi_nas_hdr_personality_get_string:
 * @val: a QmiNasHdrPersonality.
 *
 * Gets the nickname string for the #QmiNasHdrPersonality specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_hdr_personality_get_string (QmiNasHdrPersonality val);
GType qmi_nas_call_barring_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_CALL_BARRING_STATUS (qmi_nas_call_barring_status_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_CALL_BARRING_STATUS_IS_ENUM__

/**
 * qmi_nas_call_barring_status_get_string:
 * @val: a QmiNasCallBarringStatus.
 *
 * Gets the nickname string for the #QmiNasCallBarringStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_call_barring_status_get_string (QmiNasCallBarringStatus val);
GType qmi_nas_network_description_display_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_DESCRIPTION_DISPLAY (qmi_nas_network_description_display_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_DESCRIPTION_DISPLAY_IS_ENUM__

/**
 * qmi_nas_network_description_display_get_string:
 * @val: a QmiNasNetworkDescriptionDisplay.
 *
 * Gets the nickname string for the #QmiNasNetworkDescriptionDisplay specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_network_description_display_get_string (QmiNasNetworkDescriptionDisplay val);
GType qmi_nas_network_description_encoding_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_DESCRIPTION_ENCODING (qmi_nas_network_description_encoding_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_DESCRIPTION_ENCODING_IS_ENUM__

/**
 * qmi_nas_network_description_encoding_get_string:
 * @val: a QmiNasNetworkDescriptionEncoding.
 *
 * Gets the nickname string for the #QmiNasNetworkDescriptionEncoding specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_network_description_encoding_get_string (QmiNasNetworkDescriptionEncoding val);
GType qmi_nas_preference_duration_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_PREFERENCE_DURATION (qmi_nas_preference_duration_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_PREFERENCE_DURATION_IS_ENUM__

/**
 * qmi_nas_preference_duration_get_string:
 * @val: a QmiNasPreferenceDuration.
 *
 * Gets the nickname string for the #QmiNasPreferenceDuration specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_preference_duration_get_string (QmiNasPreferenceDuration val);
GType qmi_nas_cdma_prl_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_CDMA_PRL_PREFERENCE (qmi_nas_cdma_prl_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_CDMA_PRL_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_cdma_prl_preference_get_string:
 * @val: a QmiNasCdmaPrlPreference.
 *
 * Gets the nickname string for the #QmiNasCdmaPrlPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_cdma_prl_preference_get_string (QmiNasCdmaPrlPreference val);
GType qmi_nas_roaming_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_ROAMING_PREFERENCE (qmi_nas_roaming_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_ROAMING_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_roaming_preference_get_string:
 * @val: a QmiNasRoamingPreference.
 *
 * Gets the nickname string for the #QmiNasRoamingPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_roaming_preference_get_string (QmiNasRoamingPreference val);
GType qmi_nas_network_selection_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_SELECTION_PREFERENCE (qmi_nas_network_selection_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_SELECTION_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_network_selection_preference_get_string:
 * @val: a QmiNasNetworkSelectionPreference.
 *
 * Gets the nickname string for the #QmiNasNetworkSelectionPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_network_selection_preference_get_string (QmiNasNetworkSelectionPreference val);
GType qmi_nas_change_duration_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_CHANGE_DURATION (qmi_nas_change_duration_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_CHANGE_DURATION_IS_ENUM__

/**
 * qmi_nas_change_duration_get_string:
 * @val: a QmiNasChangeDuration.
 *
 * Gets the nickname string for the #QmiNasChangeDuration specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_change_duration_get_string (QmiNasChangeDuration val);
GType qmi_nas_service_domain_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SERVICE_DOMAIN_PREFERENCE (qmi_nas_service_domain_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SERVICE_DOMAIN_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_service_domain_preference_get_string:
 * @val: a QmiNasServiceDomainPreference.
 *
 * Gets the nickname string for the #QmiNasServiceDomainPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_service_domain_preference_get_string (QmiNasServiceDomainPreference val);
GType qmi_nas_gsm_wcdma_acquisition_order_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_GSM_WCDMA_ACQUISITION_ORDER_PREFERENCE (qmi_nas_gsm_wcdma_acquisition_order_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_GSM_WCDMA_ACQUISITION_ORDER_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_gsm_wcdma_acquisition_order_preference_get_string:
 * @val: a QmiNasGsmWcdmaAcquisitionOrderPreference.
 *
 * Gets the nickname string for the #QmiNasGsmWcdmaAcquisitionOrderPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_gsm_wcdma_acquisition_order_preference_get_string (QmiNasGsmWcdmaAcquisitionOrderPreference val);
GType qmi_nas_voice_domain_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_VOICE_DOMAIN_PREFERENCE (qmi_nas_voice_domain_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_VOICE_DOMAIN_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_voice_domain_preference_get_string:
 * @val: a QmiNasVoiceDomainPreference.
 *
 * Gets the nickname string for the #QmiNasVoiceDomainPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_voice_domain_preference_get_string (QmiNasVoiceDomainPreference val);
GType qmi_nas_network_selection_registration_restriction_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_SELECTION_REGISTRATION_RESTRICTION (qmi_nas_network_selection_registration_restriction_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_SELECTION_REGISTRATION_RESTRICTION_IS_ENUM__

/**
 * qmi_nas_network_selection_registration_restriction_get_string:
 * @val: a QmiNasNetworkSelectionRegistrationRestriction.
 *
 * Gets the nickname string for the #QmiNasNetworkSelectionRegistrationRestriction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_network_selection_registration_restriction_get_string (QmiNasNetworkSelectionRegistrationRestriction val);
GType qmi_nas_lte_registration_domain_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_LTE_REGISTRATION_DOMAIN (qmi_nas_lte_registration_domain_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_LTE_REGISTRATION_DOMAIN_IS_ENUM__

/**
 * qmi_nas_lte_registration_domain_get_string:
 * @val: a QmiNasLteRegistrationDomain.
 *
 * Gets the nickname string for the #QmiNasLteRegistrationDomain specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_lte_registration_domain_get_string (QmiNasLteRegistrationDomain val);
GType qmi_nas_roaming_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_ROAMING_STATUS (qmi_nas_roaming_status_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_ROAMING_STATUS_IS_ENUM__

/**
 * qmi_nas_roaming_status_get_string:
 * @val: a QmiNasRoamingStatus.
 *
 * Gets the nickname string for the #QmiNasRoamingStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_roaming_status_get_string (QmiNasRoamingStatus val);
GType qmi_nas_lte_cell_access_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_LTE_CELL_ACCESS_STATUS (qmi_nas_lte_cell_access_status_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_LTE_CELL_ACCESS_STATUS_IS_ENUM__

/**
 * qmi_nas_lte_cell_access_status_get_string:
 * @val: a QmiNasLteCellAccessStatus.
 *
 * Gets the nickname string for the #QmiNasLteCellAccessStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_lte_cell_access_status_get_string (QmiNasLteCellAccessStatus val);
GType qmi_nas_hdr_protocol_revision_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_HDR_PROTOCOL_REVISION (qmi_nas_hdr_protocol_revision_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_HDR_PROTOCOL_REVISION_IS_ENUM__

/**
 * qmi_nas_hdr_protocol_revision_get_string:
 * @val: a QmiNasHdrProtocolRevision.
 *
 * Gets the nickname string for the #QmiNasHdrProtocolRevision specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_hdr_protocol_revision_get_string (QmiNasHdrProtocolRevision val);
GType qmi_nas_wcdma_hs_service_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_WCDMA_HS_SERVICE (qmi_nas_wcdma_hs_service_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_WCDMA_HS_SERVICE_IS_ENUM__

/**
 * qmi_nas_wcdma_hs_service_get_string:
 * @val: a QmiNasWcdmaHsService.
 *
 * Gets the nickname string for the #QmiNasWcdmaHsService specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_wcdma_hs_service_get_string (QmiNasWcdmaHsService val);
GType qmi_nas_cell_broadcast_capability_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_CELL_BROADCAST_CAPABILITY (qmi_nas_cell_broadcast_capability_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_CELL_BROADCAST_CAPABILITY_IS_ENUM__

/**
 * qmi_nas_cell_broadcast_capability_get_string:
 * @val: a QmiNasCellBroadcastCapability.
 *
 * Gets the nickname string for the #QmiNasCellBroadcastCapability specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_cell_broadcast_capability_get_string (QmiNasCellBroadcastCapability val);
GType qmi_nas_sim_reject_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SIM_REJECT_STATE (qmi_nas_sim_reject_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SIM_REJECT_STATE_IS_ENUM__

/**
 * qmi_nas_sim_reject_state_get_string:
 * @val: a QmiNasSimRejectState.
 *
 * Gets the nickname string for the #QmiNasSimRejectState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_sim_reject_state_get_string (QmiNasSimRejectState val);
GType qmi_nas_cdma_pilot_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_CDMA_PILOT_TYPE (qmi_nas_cdma_pilot_type_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_CDMA_PILOT_TYPE_IS_ENUM__

/**
 * qmi_nas_cdma_pilot_type_get_string:
 * @val: a QmiNasCdmaPilotType.
 *
 * Gets the nickname string for the #QmiNasCdmaPilotType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_nas_cdma_pilot_type_get_string (QmiNasCdmaPilotType val);
GType qmi_nas_day_of_week_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_DAY_OF_WEEK (qmi_nas_day_of_week_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_DAY_OF_WEEK_IS_ENUM__

/**
 * qmi_nas_day_of_week_get_string:
 * @val: a QmiNasDayOfWeek.
 *
 * Gets the nickname string for the #QmiNasDayOfWeek specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.4
 */
const gchar *qmi_nas_day_of_week_get_string (QmiNasDayOfWeek val);
GType qmi_nas_daylight_savings_adjustment_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_DAYLIGHT_SAVINGS_ADJUSTMENT (qmi_nas_daylight_savings_adjustment_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_DAYLIGHT_SAVINGS_ADJUSTMENT_IS_ENUM__

/**
 * qmi_nas_daylight_savings_adjustment_get_string:
 * @val: a QmiNasDaylightSavingsAdjustment.
 *
 * Gets the nickname string for the #QmiNasDaylightSavingsAdjustment specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.4
 */
const gchar *qmi_nas_daylight_savings_adjustment_get_string (QmiNasDaylightSavingsAdjustment val);
GType qmi_nas_wcdma_rrc_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_WCDMA_RRC_STATE (qmi_nas_wcdma_rrc_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_WCDMA_RRC_STATE_IS_ENUM__

/**
 * qmi_nas_wcdma_rrc_state_get_string:
 * @val: a QmiNasWcdmaRrcState.
 *
 * Gets the nickname string for the #QmiNasWcdmaRrcState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_nas_wcdma_rrc_state_get_string (QmiNasWcdmaRrcState val);
GType qmi_nas_dl_bandwidth_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_DL_BANDWIDTH (qmi_nas_dl_bandwidth_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_DL_BANDWIDTH_IS_ENUM__

/**
 * qmi_nas_dl_bandwidth_get_string:
 * @val: a QmiNasDLBandwidth.
 *
 * Gets the nickname string for the #QmiNasDLBandwidth specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.16
 */
const gchar *qmi_nas_dl_bandwidth_get_string (QmiNasDLBandwidth val);
GType qmi_nas_scell_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SCELL_STATE (qmi_nas_scell_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SCELL_STATE_IS_ENUM__

/**
 * qmi_nas_scell_state_get_string:
 * @val: a QmiNasScellState.
 *
 * Gets the nickname string for the #QmiNasScellState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.16
 */
const gchar *qmi_nas_scell_state_get_string (QmiNasScellState val);
GType qmi_nas_plmn_encoding_scheme_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_PLMN_ENCODING_SCHEME (qmi_nas_plmn_encoding_scheme_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_PLMN_ENCODING_SCHEME_IS_ENUM__

/**
 * qmi_nas_plmn_encoding_scheme_get_string:
 * @val: a QmiNasPlmnEncodingScheme.
 *
 * Gets the nickname string for the #QmiNasPlmnEncodingScheme specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_nas_plmn_encoding_scheme_get_string (QmiNasPlmnEncodingScheme val);
GType qmi_nas_plmn_name_country_initials_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_PLMN_NAME_COUNTRY_INITIALS (qmi_nas_plmn_name_country_initials_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_PLMN_NAME_COUNTRY_INITIALS_IS_ENUM__

/**
 * qmi_nas_plmn_name_country_initials_get_string:
 * @val: a QmiNasPlmnNameCountryInitials.
 *
 * Gets the nickname string for the #QmiNasPlmnNameCountryInitials specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_nas_plmn_name_country_initials_get_string (QmiNasPlmnNameCountryInitials val);
GType qmi_nas_network_name_source_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_NETWORK_NAME_SOURCE (qmi_nas_network_name_source_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_NETWORK_NAME_SOURCE_IS_ENUM__

/**
 * qmi_nas_network_name_source_get_string:
 * @val: a QmiNasNetworkNameSource.
 *
 * Gets the nickname string for the #QmiNasNetworkNameSource specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_network_name_source_get_string (QmiNasNetworkNameSource val);
GType qmi_nas_plmn_name_spare_bits_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_PLMN_NAME_SPARE_BITS (qmi_nas_plmn_name_spare_bits_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_PLMN_NAME_SPARE_BITS_IS_ENUM__

/**
 * qmi_nas_plmn_name_spare_bits_get_string:
 * @val: a QmiNasPlmnNameSpareBits.
 *
 * Gets the nickname string for the #QmiNasPlmnNameSpareBits specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_nas_plmn_name_spare_bits_get_string (QmiNasPlmnNameSpareBits val);
GType qmi_nas_usage_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_USAGE_PREFERENCE (qmi_nas_usage_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_USAGE_PREFERENCE_IS_ENUM__

/**
 * qmi_nas_usage_preference_get_string:
 * @val: a QmiNasUsagePreference.
 *
 * Gets the nickname string for the #QmiNasUsagePreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_usage_preference_get_string (QmiNasUsagePreference val);
GType qmi_nas_swi_modem_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SWI_MODEM_MODE (qmi_nas_swi_modem_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SWI_MODEM_MODE_IS_ENUM__

/**
 * qmi_nas_swi_modem_mode_get_string:
 * @val: a QmiNasSwiModemMode.
 *
 * Gets the nickname string for the #QmiNasSwiModemMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_swi_modem_mode_get_string (QmiNasSwiModemMode val);
GType qmi_nas_swi_system_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SWI_SYSTEM_MODE (qmi_nas_swi_system_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SWI_SYSTEM_MODE_IS_ENUM__

/**
 * qmi_nas_swi_system_mode_get_string:
 * @val: a QmiNasSwiSystemMode.
 *
 * Gets the nickname string for the #QmiNasSwiSystemMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_swi_system_mode_get_string (QmiNasSwiSystemMode val);
GType qmi_nas_swi_ims_reg_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SWI_IMS_REG_STATE (qmi_nas_swi_ims_reg_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SWI_IMS_REG_STATE_IS_ENUM__

/**
 * qmi_nas_swi_ims_reg_state_get_string:
 * @val: a QmiNasSwiImsRegState.
 *
 * Gets the nickname string for the #QmiNasSwiImsRegState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_swi_ims_reg_state_get_string (QmiNasSwiImsRegState val);
GType qmi_nas_swi_ps_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SWI_PS_STATE (qmi_nas_swi_ps_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SWI_PS_STATE_IS_ENUM__

/**
 * qmi_nas_swi_ps_state_get_string:
 * @val: a QmiNasSwiPsState.
 *
 * Gets the nickname string for the #QmiNasSwiPsState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_swi_ps_state_get_string (QmiNasSwiPsState val);
GType qmi_nas_swi_emm_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SWI_EMM_STATE (qmi_nas_swi_emm_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SWI_EMM_STATE_IS_ENUM__

/**
 * qmi_nas_swi_emm_state_get_string:
 * @val: a QmiNasSwiEmmState.
 *
 * Gets the nickname string for the #QmiNasSwiEmmState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_swi_emm_state_get_string (QmiNasSwiEmmState val);
GType qmi_nas_swi_emm_connection_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_SWI_EMM_CONNECTION_STATE (qmi_nas_swi_emm_connection_state_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_SWI_EMM_CONNECTION_STATE_IS_ENUM__

/**
 * qmi_nas_swi_emm_connection_state_get_string:
 * @val: a QmiNasSwiEmmConnectionState.
 *
 * Gets the nickname string for the #QmiNasSwiEmmConnectionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.24
 */
const gchar *qmi_nas_swi_emm_connection_state_get_string (QmiNasSwiEmmConnectionState val);
GType qmi_nas_drx_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_DRX (qmi_nas_drx_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_DRX_IS_ENUM__

/**
 * qmi_nas_drx_get_string:
 * @val: a QmiNasDrx.
 *
 * Gets the nickname string for the #QmiNasDrx specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_nas_drx_get_string (QmiNasDrx val);
GType qmi_nas_boolean_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_BOOLEAN (qmi_nas_boolean_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_BOOLEAN_IS_ENUM__

/**
 * qmi_nas_boolean_get_string:
 * @val: a QmiNasBoolean.
 *
 * Gets the nickname string for the #QmiNasBoolean specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_nas_boolean_get_string (QmiNasBoolean val);
GType qmi_nas_plmn_language_id_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_PLMN_LANGUAGE_ID (qmi_nas_plmn_language_id_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_PLMN_LANGUAGE_ID_IS_ENUM__

/**
 * qmi_nas_plmn_language_id_get_string:
 * @val: a QmiNasPlmnLanguageId.
 *
 * Gets the nickname string for the #QmiNasPlmnLanguageId specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_nas_plmn_language_id_get_string (QmiNasPlmnLanguageId val);
GType qmi_nas_lte_voice_domain_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_LTE_VOICE_DOMAIN (qmi_nas_lte_voice_domain_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_LTE_VOICE_DOMAIN_IS_ENUM__

/**
 * qmi_nas_lte_voice_domain_get_string:
 * @val: a QmiNasLteVoiceDomain.
 *
 * Gets the nickname string for the #QmiNasLteVoiceDomain specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_nas_lte_voice_domain_get_string (QmiNasLteVoiceDomain val);
GType qmi_nas_reject_cause_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_NAS_REJECT_CAUSE (qmi_nas_reject_cause_get_type ())

/* Define type-specific symbols */
#define __QMI_NAS_REJECT_CAUSE_IS_ENUM__

/**
 * qmi_nas_reject_cause_get_string:
 * @val: a QmiNasRejectCause.
 *
 * Gets the nickname string for the #QmiNasRejectCause specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.30
 */
const gchar *qmi_nas_reject_cause_get_string (QmiNasRejectCause val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-oma.h" */
GType qmi_oma_session_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_OMA_SESSION_TYPE (qmi_oma_session_type_get_type ())

/* Define type-specific symbols */
#define __QMI_OMA_SESSION_TYPE_IS_ENUM__

/**
 * qmi_oma_session_type_get_string:
 * @val: a QmiOmaSessionType.
 *
 * Gets the nickname string for the #QmiOmaSessionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_oma_session_type_get_string (QmiOmaSessionType val);
GType qmi_oma_session_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_OMA_SESSION_STATE (qmi_oma_session_state_get_type ())

/* Define type-specific symbols */
#define __QMI_OMA_SESSION_STATE_IS_ENUM__

/**
 * qmi_oma_session_state_get_string:
 * @val: a QmiOmaSessionState.
 *
 * Gets the nickname string for the #QmiOmaSessionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_oma_session_state_get_string (QmiOmaSessionState val);
GType qmi_oma_session_failed_reason_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_OMA_SESSION_FAILED_REASON (qmi_oma_session_failed_reason_get_type ())

/* Define type-specific symbols */
#define __QMI_OMA_SESSION_FAILED_REASON_IS_ENUM__

/**
 * qmi_oma_session_failed_reason_get_string:
 * @val: a QmiOmaSessionFailedReason.
 *
 * Gets the nickname string for the #QmiOmaSessionFailedReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_oma_session_failed_reason_get_string (QmiOmaSessionFailedReason val);
GType qmi_oma_hfa_feature_done_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_OMA_HFA_FEATURE_DONE_STATE (qmi_oma_hfa_feature_done_state_get_type ())

/* Define type-specific symbols */
#define __QMI_OMA_HFA_FEATURE_DONE_STATE_IS_ENUM__

/**
 * qmi_oma_hfa_feature_done_state_get_string:
 * @val: a QmiOmaHfaFeatureDoneState.
 *
 * Gets the nickname string for the #QmiOmaHfaFeatureDoneState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_oma_hfa_feature_done_state_get_string (QmiOmaHfaFeatureDoneState val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-pbm.h" */
GType qmi_pbm_session_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PBM_SESSION_TYPE (qmi_pbm_session_type_get_type ())

/* Define type-specific symbols */
#define __QMI_PBM_SESSION_TYPE_IS_ENUM__

/**
 * qmi_pbm_session_type_get_string:
 * @val: a QmiPbmSessionType.
 *
 * Gets the nickname string for the #QmiPbmSessionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_pbm_session_type_get_string (QmiPbmSessionType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-pdc.h" */
GType qmi_pdc_configuration_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDC_CONFIGURATION_TYPE (qmi_pdc_configuration_type_get_type ())

/* Define type-specific symbols */
#define __QMI_PDC_CONFIGURATION_TYPE_IS_ENUM__

/**
 * qmi_pdc_configuration_type_get_string:
 * @val: a QmiPdcConfigurationType.
 *
 * Gets the nickname string for the #QmiPdcConfigurationType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_pdc_configuration_type_get_string (QmiPdcConfigurationType val);
GType qmi_pdc_refresh_event_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDC_REFRESH_EVENT_TYPE (qmi_pdc_refresh_event_type_get_type ())

/* Define type-specific symbols */
#define __QMI_PDC_REFRESH_EVENT_TYPE_IS_ENUM__

/**
 * qmi_pdc_refresh_event_type_get_string:
 * @val: a QmiPdcRefreshEventType.
 *
 * Gets the nickname string for the #QmiPdcRefreshEventType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.32
 */
const gchar *qmi_pdc_refresh_event_type_get_string (QmiPdcRefreshEventType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-pds.h" */
GType qmi_pds_operation_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDS_OPERATION_MODE (qmi_pds_operation_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_PDS_OPERATION_MODE_IS_ENUM__

/**
 * qmi_pds_operation_mode_get_string:
 * @val: a QmiPdsOperationMode.
 *
 * Gets the nickname string for the #QmiPdsOperationMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_pds_operation_mode_get_string (QmiPdsOperationMode val);
GType qmi_pds_position_session_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDS_POSITION_SESSION_STATUS (qmi_pds_position_session_status_get_type ())

/* Define type-specific symbols */
#define __QMI_PDS_POSITION_SESSION_STATUS_IS_ENUM__

/**
 * qmi_pds_position_session_status_get_string:
 * @val: a QmiPdsPositionSessionStatus.
 *
 * Gets the nickname string for the #QmiPdsPositionSessionStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_pds_position_session_status_get_string (QmiPdsPositionSessionStatus val);
GType qmi_pds_tracking_session_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDS_TRACKING_SESSION_STATE (qmi_pds_tracking_session_state_get_type ())

/* Define type-specific symbols */
#define __QMI_PDS_TRACKING_SESSION_STATE_IS_ENUM__

/**
 * qmi_pds_tracking_session_state_get_string:
 * @val: a QmiPdsTrackingSessionState.
 *
 * Gets the nickname string for the #QmiPdsTrackingSessionState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_pds_tracking_session_state_get_string (QmiPdsTrackingSessionState val);
GType qmi_pds_operating_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDS_OPERATING_MODE (qmi_pds_operating_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_PDS_OPERATING_MODE_IS_ENUM__

/**
 * qmi_pds_operating_mode_get_string:
 * @val: a QmiPdsOperatingMode.
 *
 * Gets the nickname string for the #QmiPdsOperatingMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.12
 */
const gchar *qmi_pds_operating_mode_get_string (QmiPdsOperatingMode val);
GType qmi_pds_network_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_PDS_NETWORK_MODE (qmi_pds_network_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_PDS_NETWORK_MODE_IS_ENUM__

/**
 * qmi_pds_network_mode_get_string:
 * @val: a QmiPdsNetworkMode.
 *
 * Gets the nickname string for the #QmiPdsNetworkMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.12
 */
const gchar *qmi_pds_network_mode_get_string (QmiPdsNetworkMode val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-qos.h" */
GType qmi_qos_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_QOS_STATUS (qmi_qos_status_get_type ())

/* Define type-specific symbols */
#define __QMI_QOS_STATUS_IS_ENUM__

/**
 * qmi_qos_status_get_string:
 * @val: a QmiQosStatus.
 *
 * Gets the nickname string for the #QmiQosStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_qos_status_get_string (QmiQosStatus val);
GType qmi_qos_event_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_QOS_EVENT (qmi_qos_event_get_type ())

/* Define type-specific symbols */
#define __QMI_QOS_EVENT_IS_ENUM__

/**
 * qmi_qos_event_get_string:
 * @val: a QmiQosEvent.
 *
 * Gets the nickname string for the #QmiQosEvent specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_qos_event_get_string (QmiQosEvent val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-sar.h" */
GType qmi_sar_rf_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_SAR_RF_STATE (qmi_sar_rf_state_get_type ())

/* Define type-specific symbols */
#define __QMI_SAR_RF_STATE_IS_ENUM__

/**
 * qmi_sar_rf_state_get_string:
 * @val: a QmiSarRfState.
 *
 * Gets the nickname string for the #QmiSarRfState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_sar_rf_state_get_string (QmiSarRfState val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-ssc.h" */
GType qmi_ssc_report_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_SSC_REPORT_TYPE (qmi_ssc_report_type_get_type ())

/* Define type-specific symbols */
#define __QMI_SSC_REPORT_TYPE_IS_ENUM__

/**
 * qmi_ssc_report_type_get_string:
 * @val: a QmiSscReportType.
 *
 * Gets the nickname string for the #QmiSscReportType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_ssc_report_type_get_string (QmiSscReportType val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-uim.h" */
GType qmi_uim_session_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_SESSION_TYPE (qmi_uim_session_type_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_SESSION_TYPE_IS_ENUM__

/**
 * qmi_uim_session_type_get_string:
 * @val: a QmiUimSessionType.
 *
 * Gets the nickname string for the #QmiUimSessionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_uim_session_type_get_string (QmiUimSessionType val);
GType qmi_uim_file_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_FILE_TYPE (qmi_uim_file_type_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_FILE_TYPE_IS_ENUM__

/**
 * qmi_uim_file_type_get_string:
 * @val: a QmiUimFileType.
 *
 * Gets the nickname string for the #QmiUimFileType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_uim_file_type_get_string (QmiUimFileType val);
GType qmi_uim_security_attribute_logic_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_SECURITY_ATTRIBUTE_LOGIC (qmi_uim_security_attribute_logic_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_SECURITY_ATTRIBUTE_LOGIC_IS_ENUM__

/**
 * qmi_uim_security_attribute_logic_get_string:
 * @val: a QmiUimSecurityAttributeLogic.
 *
 * Gets the nickname string for the #QmiUimSecurityAttributeLogic specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.6
 */
const gchar *qmi_uim_security_attribute_logic_get_string (QmiUimSecurityAttributeLogic val);
GType qmi_uim_pin_id_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_PIN_ID (qmi_uim_pin_id_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_PIN_ID_IS_ENUM__

/**
 * qmi_uim_pin_id_get_string:
 * @val: a QmiUimPinId.
 *
 * Gets the nickname string for the #QmiUimPinId specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_uim_pin_id_get_string (QmiUimPinId val);
GType qmi_uim_card_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_STATE (qmi_uim_card_state_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_STATE_IS_ENUM__

/**
 * qmi_uim_card_state_get_string:
 * @val: a QmiUimCardState.
 *
 * Gets the nickname string for the #QmiUimCardState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_card_state_get_string (QmiUimCardState val);
GType qmi_uim_pin_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_PIN_STATE (qmi_uim_pin_state_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_PIN_STATE_IS_ENUM__

/**
 * qmi_uim_pin_state_get_string:
 * @val: a QmiUimPinState.
 *
 * Gets the nickname string for the #QmiUimPinState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_pin_state_get_string (QmiUimPinState val);
GType qmi_uim_card_error_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_ERROR (qmi_uim_card_error_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_ERROR_IS_ENUM__

/**
 * qmi_uim_card_error_get_string:
 * @val: a QmiUimCardError.
 *
 * Gets the nickname string for the #QmiUimCardError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_card_error_get_string (QmiUimCardError val);
GType qmi_uim_card_application_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_APPLICATION_TYPE (qmi_uim_card_application_type_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_APPLICATION_TYPE_IS_ENUM__

/**
 * qmi_uim_card_application_type_get_string:
 * @val: a QmiUimCardApplicationType.
 *
 * Gets the nickname string for the #QmiUimCardApplicationType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_card_application_type_get_string (QmiUimCardApplicationType val);
GType qmi_uim_card_application_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_APPLICATION_STATE (qmi_uim_card_application_state_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_APPLICATION_STATE_IS_ENUM__

/**
 * qmi_uim_card_application_state_get_string:
 * @val: a QmiUimCardApplicationState.
 *
 * Gets the nickname string for the #QmiUimCardApplicationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_card_application_state_get_string (QmiUimCardApplicationState val);
GType qmi_uim_card_application_personalization_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_APPLICATION_PERSONALIZATION_STATE (qmi_uim_card_application_personalization_state_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_APPLICATION_PERSONALIZATION_STATE_IS_ENUM__

/**
 * qmi_uim_card_application_personalization_state_get_string:
 * @val: a QmiUimCardApplicationPersonalizationState.
 *
 * Gets the nickname string for the #QmiUimCardApplicationPersonalizationState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_card_application_personalization_state_get_string (QmiUimCardApplicationPersonalizationState val);
GType qmi_uim_card_application_personalization_feature_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE (qmi_uim_card_application_personalization_feature_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_IS_ENUM__

/**
 * qmi_uim_card_application_personalization_feature_get_string:
 * @val: a QmiUimCardApplicationPersonalizationFeature.
 *
 * Gets the nickname string for the #QmiUimCardApplicationPersonalizationFeature specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_uim_card_application_personalization_feature_get_string (QmiUimCardApplicationPersonalizationFeature val);
GType qmi_uim_card_application_personalization_feature_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_STATUS (qmi_uim_card_application_personalization_feature_status_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_APPLICATION_PERSONALIZATION_FEATURE_STATUS_IS_ENUM__

/**
 * qmi_uim_card_application_personalization_feature_status_get_string:
 * @val: a QmiUimCardApplicationPersonalizationFeatureStatus.
 *
 * Gets the nickname string for the #QmiUimCardApplicationPersonalizationFeatureStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_uim_card_application_personalization_feature_status_get_string (QmiUimCardApplicationPersonalizationFeatureStatus val);
GType qmi_uim_refresh_stage_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_REFRESH_STAGE (qmi_uim_refresh_stage_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_REFRESH_STAGE_IS_ENUM__

/**
 * qmi_uim_refresh_stage_get_string:
 * @val: a QmiUimRefreshStage.
 *
 * Gets the nickname string for the #QmiUimRefreshStage specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_uim_refresh_stage_get_string (QmiUimRefreshStage val);
GType qmi_uim_refresh_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_REFRESH_MODE (qmi_uim_refresh_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_REFRESH_MODE_IS_ENUM__

/**
 * qmi_uim_refresh_mode_get_string:
 * @val: a QmiUimRefreshMode.
 *
 * Gets the nickname string for the #QmiUimRefreshMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_uim_refresh_mode_get_string (QmiUimRefreshMode val);
GType qmi_uim_physical_card_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_PHYSICAL_CARD_STATE (qmi_uim_physical_card_state_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_PHYSICAL_CARD_STATE_IS_ENUM__

/**
 * qmi_uim_physical_card_state_get_string:
 * @val: a QmiUimPhysicalCardState.
 *
 * Gets the nickname string for the #QmiUimPhysicalCardState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_uim_physical_card_state_get_string (QmiUimPhysicalCardState val);
GType qmi_uim_slot_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_SLOT_STATE (qmi_uim_slot_state_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_SLOT_STATE_IS_ENUM__

/**
 * qmi_uim_slot_state_get_string:
 * @val: a QmiUimSlotState.
 *
 * Gets the nickname string for the #QmiUimSlotState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_uim_slot_state_get_string (QmiUimSlotState val);
GType qmi_uim_card_protocol_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_CARD_PROTOCOL (qmi_uim_card_protocol_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_CARD_PROTOCOL_IS_ENUM__

/**
 * qmi_uim_card_protocol_get_string:
 * @val: a QmiUimCardProtocol.
 *
 * Gets the nickname string for the #QmiUimCardProtocol specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_uim_card_protocol_get_string (QmiUimCardProtocol val);
GType qmi_uim_depersonalization_operation_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_UIM_DEPERSONALIZATION_OPERATION (qmi_uim_depersonalization_operation_get_type ())

/* Define type-specific symbols */
#define __QMI_UIM_DEPERSONALIZATION_OPERATION_IS_ENUM__

/**
 * qmi_uim_depersonalization_operation_get_string:
 * @val: a QmiUimDepersonalizationOperation.
 *
 * Gets the nickname string for the #QmiUimDepersonalizationOperation specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.30
 */
const gchar *qmi_uim_depersonalization_operation_get_string (QmiUimDepersonalizationOperation val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-voice.h" */
GType qmi_voice_call_state_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_STATE (qmi_voice_call_state_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_STATE_IS_ENUM__

/**
 * qmi_voice_call_state_get_string:
 * @val: a QmiVoiceCallState.
 *
 * Gets the nickname string for the #QmiVoiceCallState specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_call_state_get_string (QmiVoiceCallState val);
GType qmi_voice_call_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_TYPE (qmi_voice_call_type_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_TYPE_IS_ENUM__

/**
 * qmi_voice_call_type_get_string:
 * @val: a QmiVoiceCallType.
 *
 * Gets the nickname string for the #QmiVoiceCallType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_call_type_get_string (QmiVoiceCallType val);
GType qmi_voice_call_direction_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_DIRECTION (qmi_voice_call_direction_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_DIRECTION_IS_ENUM__

/**
 * qmi_voice_call_direction_get_string:
 * @val: a QmiVoiceCallDirection.
 *
 * Gets the nickname string for the #QmiVoiceCallDirection specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_call_direction_get_string (QmiVoiceCallDirection val);
GType qmi_voice_call_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_MODE (qmi_voice_call_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_MODE_IS_ENUM__

/**
 * qmi_voice_call_mode_get_string:
 * @val: a QmiVoiceCallMode.
 *
 * Gets the nickname string for the #QmiVoiceCallMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_call_mode_get_string (QmiVoiceCallMode val);
GType qmi_voice_als_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_ALS (qmi_voice_als_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_ALS_IS_ENUM__

/**
 * qmi_voice_als_get_string:
 * @val: a QmiVoiceAls.
 *
 * Gets the nickname string for the #QmiVoiceAls specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_als_get_string (QmiVoiceAls val);
GType qmi_voice_presentation_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_PRESENTATION (qmi_voice_presentation_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_PRESENTATION_IS_ENUM__

/**
 * qmi_voice_presentation_get_string:
 * @val: a QmiVoicePresentation.
 *
 * Gets the nickname string for the #QmiVoicePresentation specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_presentation_get_string (QmiVoicePresentation val);
GType qmi_voice_tty_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_TTY_MODE (qmi_voice_tty_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_TTY_MODE_IS_ENUM__

/**
 * qmi_voice_tty_mode_get_string:
 * @val: a QmiVoiceTtyMode.
 *
 * Gets the nickname string for the #QmiVoiceTtyMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_tty_mode_get_string (QmiVoiceTtyMode val);
GType qmi_voice_service_option_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_SERVICE_OPTION (qmi_voice_service_option_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_SERVICE_OPTION_IS_ENUM__

/**
 * qmi_voice_service_option_get_string:
 * @val: a QmiVoiceServiceOption.
 *
 * Gets the nickname string for the #QmiVoiceServiceOption specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_service_option_get_string (QmiVoiceServiceOption val);
GType qmi_voice_privacy_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_PRIVACY (qmi_voice_privacy_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_PRIVACY_IS_ENUM__

/**
 * qmi_voice_privacy_get_string:
 * @val: a QmiVoicePrivacy.
 *
 * Gets the nickname string for the #QmiVoicePrivacy specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_privacy_get_string (QmiVoicePrivacy val);
GType qmi_voice_domain_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_DOMAIN (qmi_voice_domain_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_DOMAIN_IS_ENUM__

/**
 * qmi_voice_domain_get_string:
 * @val: a QmiVoiceDomain.
 *
 * Gets the nickname string for the #QmiVoiceDomain specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_voice_domain_get_string (QmiVoiceDomain val);
GType qmi_voice_user_action_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_USER_ACTION (qmi_voice_user_action_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_USER_ACTION_IS_ENUM__

/**
 * qmi_voice_user_action_get_string:
 * @val: a QmiVoiceUserAction.
 *
 * Gets the nickname string for the #QmiVoiceUserAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_voice_user_action_get_string (QmiVoiceUserAction val);
GType qmi_voice_uss_data_coding_scheme_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_USS_DATA_CODING_SCHEME (qmi_voice_uss_data_coding_scheme_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_USS_DATA_CODING_SCHEME_IS_ENUM__

/**
 * qmi_voice_uss_data_coding_scheme_get_string:
 * @val: a QmiVoiceUssDataCodingScheme.
 *
 * Gets the nickname string for the #QmiVoiceUssDataCodingScheme specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_voice_uss_data_coding_scheme_get_string (QmiVoiceUssDataCodingScheme val);
GType qmi_voice_alpha_data_coding_scheme_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_ALPHA_DATA_CODING_SCHEME (qmi_voice_alpha_data_coding_scheme_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_ALPHA_DATA_CODING_SCHEME_IS_ENUM__

/**
 * qmi_voice_alpha_data_coding_scheme_get_string:
 * @val: a QmiVoiceAlphaDataCodingScheme.
 *
 * Gets the nickname string for the #QmiVoiceAlphaDataCodingScheme specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_voice_alpha_data_coding_scheme_get_string (QmiVoiceAlphaDataCodingScheme val);
GType qmi_voice_call_end_reason_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_END_REASON (qmi_voice_call_end_reason_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_END_REASON_IS_ENUM__

/**
 * qmi_voice_call_end_reason_get_string:
 * @val: a QmiVoiceCallEndReason.
 *
 * Gets the nickname string for the #QmiVoiceCallEndReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_voice_call_end_reason_get_string (QmiVoiceCallEndReason val);
GType qmi_voice_call_control_result_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_CONTROL_RESULT_TYPE (qmi_voice_call_control_result_type_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_CONTROL_RESULT_TYPE_IS_ENUM__

/**
 * qmi_voice_call_control_result_type_get_string:
 * @val: a QmiVoiceCallControlResultType.
 *
 * Gets the nickname string for the #QmiVoiceCallControlResultType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_voice_call_control_result_type_get_string (QmiVoiceCallControlResultType val);
GType qmi_voice_call_control_supplementary_service_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_CALL_CONTROL_SUPPLEMENTARY_SERVICE_TYPE (qmi_voice_call_control_supplementary_service_type_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_CALL_CONTROL_SUPPLEMENTARY_SERVICE_TYPE_IS_ENUM__

/**
 * qmi_voice_call_control_supplementary_service_type_get_string:
 * @val: a QmiVoiceCallControlSupplementaryServiceType.
 *
 * Gets the nickname string for the #QmiVoiceCallControlSupplementaryServiceType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.26
 */
const gchar *qmi_voice_call_control_supplementary_service_type_get_string (QmiVoiceCallControlSupplementaryServiceType val);
GType qmi_voice_supplementary_service_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_SUPPLEMENTARY_SERVICE_TYPE (qmi_voice_supplementary_service_type_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_IS_ENUM__

/**
 * qmi_voice_supplementary_service_type_get_string:
 * @val: a QmiVoiceSupplementaryServiceType.
 *
 * Gets the nickname string for the #QmiVoiceSupplementaryServiceType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.30
 */
const gchar *qmi_voice_supplementary_service_type_get_string (QmiVoiceSupplementaryServiceType val);
GType qmi_voice_supplementary_service_notification_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE (qmi_voice_supplementary_service_notification_type_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_IS_ENUM__

/**
 * qmi_voice_supplementary_service_notification_type_get_string:
 * @val: a QmiVoiceSupplementaryServiceNotificationType.
 *
 * Gets the nickname string for the #QmiVoiceSupplementaryServiceNotificationType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.30
 */
const gchar *qmi_voice_supplementary_service_notification_type_get_string (QmiVoiceSupplementaryServiceNotificationType val);
GType qmi_voice_supplementary_service_action_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_SUPPLEMENTARY_SERVICE_ACTION (qmi_voice_supplementary_service_action_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_IS_ENUM__

/**
 * qmi_voice_supplementary_service_action_get_string:
 * @val: a QmiVoiceSupplementaryServiceAction.
 *
 * Gets the nickname string for the #QmiVoiceSupplementaryServiceAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.30
 */
const gchar *qmi_voice_supplementary_service_action_get_string (QmiVoiceSupplementaryServiceAction val);
GType qmi_voice_supplementary_service_reason_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_VOICE_SUPPLEMENTARY_SERVICE_REASON (qmi_voice_supplementary_service_reason_get_type ())

/* Define type-specific symbols */
#define __QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_IS_ENUM__

/**
 * qmi_voice_supplementary_service_reason_get_string:
 * @val: a QmiVoiceSupplementaryServiceReason.
 *
 * Gets the nickname string for the #QmiVoiceSupplementaryServiceReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.30
 */
const gchar *qmi_voice_supplementary_service_reason_get_string (QmiVoiceSupplementaryServiceReason val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-wda.h" */
GType qmi_wda_link_layer_protocol_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDA_LINK_LAYER_PROTOCOL (qmi_wda_link_layer_protocol_get_type ())

/* Define type-specific symbols */
#define __QMI_WDA_LINK_LAYER_PROTOCOL_IS_ENUM__

/**
 * qmi_wda_link_layer_protocol_get_string:
 * @val: a QmiWdaLinkLayerProtocol.
 *
 * Gets the nickname string for the #QmiWdaLinkLayerProtocol specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_wda_link_layer_protocol_get_string (QmiWdaLinkLayerProtocol val);
GType qmi_wda_data_aggregation_protocol_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDA_DATA_AGGREGATION_PROTOCOL (qmi_wda_data_aggregation_protocol_get_type ())

/* Define type-specific symbols */
#define __QMI_WDA_DATA_AGGREGATION_PROTOCOL_IS_ENUM__

/**
 * qmi_wda_data_aggregation_protocol_get_string:
 * @val: a QmiWdaDataAggregationProtocol.
 *
 * Gets the nickname string for the #QmiWdaDataAggregationProtocol specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.10
 */
const gchar *qmi_wda_data_aggregation_protocol_get_string (QmiWdaDataAggregationProtocol val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-wds.h" */
GType qmi_wds_ip_family_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_IP_FAMILY (qmi_wds_ip_family_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_IP_FAMILY_IS_ENUM__

/**
 * qmi_wds_ip_family_get_string:
 * @val: a QmiWdsIpFamily.
 *
 * Gets the nickname string for the #QmiWdsIpFamily specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_ip_family_get_string (QmiWdsIpFamily val);
GType qmi_wds_extended_technology_preference_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_EXTENDED_TECHNOLOGY_PREFERENCE (qmi_wds_extended_technology_preference_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_EXTENDED_TECHNOLOGY_PREFERENCE_IS_ENUM__

/**
 * qmi_wds_extended_technology_preference_get_string:
 * @val: a QmiWdsExtendedTechnologyPreference.
 *
 * Gets the nickname string for the #QmiWdsExtendedTechnologyPreference specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_extended_technology_preference_get_string (QmiWdsExtendedTechnologyPreference val);
GType qmi_wds_call_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_CALL_TYPE (qmi_wds_call_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_CALL_TYPE_IS_ENUM__

/**
 * qmi_wds_call_type_get_string:
 * @val: a QmiWdsCallType.
 *
 * Gets the nickname string for the #QmiWdsCallType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_call_type_get_string (QmiWdsCallType val);
GType qmi_wds_call_end_reason_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_CALL_END_REASON (qmi_wds_call_end_reason_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_CALL_END_REASON_IS_ENUM__

/**
 * qmi_wds_call_end_reason_get_string:
 * @val: a QmiWdsCallEndReason.
 *
 * Gets the nickname string for the #QmiWdsCallEndReason specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_call_end_reason_get_string (QmiWdsCallEndReason val);
GType qmi_wds_verbose_call_end_reason_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_TYPE (qmi_wds_verbose_call_end_reason_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_TYPE_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_type_get_string:
 * @val: a QmiWdsVerboseCallEndReasonType.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_type_get_string (QmiWdsVerboseCallEndReasonType val);
GType qmi_wds_verbose_call_end_reason_mip_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_MIP (qmi_wds_verbose_call_end_reason_mip_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_MIP_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_mip_get_string:
 * @val: a QmiWdsVerboseCallEndReasonMip.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonMip specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_mip_get_string (QmiWdsVerboseCallEndReasonMip val);
GType qmi_wds_verbose_call_end_reason_internal_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_INTERNAL (qmi_wds_verbose_call_end_reason_internal_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_INTERNAL_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_internal_get_string:
 * @val: a QmiWdsVerboseCallEndReasonInternal.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonInternal specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_internal_get_string (QmiWdsVerboseCallEndReasonInternal val);
GType qmi_wds_verbose_call_end_reason_cm_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_CM (qmi_wds_verbose_call_end_reason_cm_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_CM_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_cm_get_string:
 * @val: a QmiWdsVerboseCallEndReasonCm.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonCm specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_cm_get_string (QmiWdsVerboseCallEndReasonCm val);
GType qmi_wds_verbose_call_end_reason_3gpp_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_3GPP (qmi_wds_verbose_call_end_reason_3gpp_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_3GPP_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_3gpp_get_string:
 * @val: a QmiWdsVerboseCallEndReason3gpp.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReason3gpp specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_3gpp_get_string (QmiWdsVerboseCallEndReason3gpp val);
GType qmi_wds_verbose_call_end_reason_ppp_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_PPP (qmi_wds_verbose_call_end_reason_ppp_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_PPP_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_ppp_get_string:
 * @val: a QmiWdsVerboseCallEndReasonPpp.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonPpp specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_ppp_get_string (QmiWdsVerboseCallEndReasonPpp val);
GType qmi_wds_verbose_call_end_reason_ehrpd_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_EHRPD (qmi_wds_verbose_call_end_reason_ehrpd_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_EHRPD_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_ehrpd_get_string:
 * @val: a QmiWdsVerboseCallEndReasonEhrpd.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonEhrpd specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_ehrpd_get_string (QmiWdsVerboseCallEndReasonEhrpd val);
GType qmi_wds_verbose_call_end_reason_ipv6_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_VERBOSE_CALL_END_REASON_IPV6 (qmi_wds_verbose_call_end_reason_ipv6_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_VERBOSE_CALL_END_REASON_IPV6_IS_ENUM__

/**
 * qmi_wds_verbose_call_end_reason_ipv6_get_string:
 * @val: a QmiWdsVerboseCallEndReasonIpv6.
 *
 * Gets the nickname string for the #QmiWdsVerboseCallEndReasonIpv6 specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_verbose_call_end_reason_ipv6_get_string (QmiWdsVerboseCallEndReasonIpv6 val);
GType qmi_wds_connection_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_CONNECTION_STATUS (qmi_wds_connection_status_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_CONNECTION_STATUS_IS_ENUM__

/**
 * qmi_wds_connection_status_get_string:
 * @val: a QmiWdsConnectionStatus.
 *
 * Gets the nickname string for the #QmiWdsConnectionStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_connection_status_get_string (QmiWdsConnectionStatus val);
GType qmi_wds_data_bearer_technology_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DATA_BEARER_TECHNOLOGY (qmi_wds_data_bearer_technology_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DATA_BEARER_TECHNOLOGY_IS_ENUM__

/**
 * qmi_wds_data_bearer_technology_get_string:
 * @val: a QmiWdsDataBearerTechnology.
 *
 * Gets the nickname string for the #QmiWdsDataBearerTechnology specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_data_bearer_technology_get_string (QmiWdsDataBearerTechnology val);
GType qmi_wds_network_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_NETWORK_TYPE (qmi_wds_network_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_NETWORK_TYPE_IS_ENUM__

/**
 * qmi_wds_network_type_get_string:
 * @val: a QmiWdsNetworkType.
 *
 * Gets the nickname string for the #QmiWdsNetworkType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_network_type_get_string (QmiWdsNetworkType val);
GType qmi_wds_data_system_network_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DATA_SYSTEM_NETWORK_TYPE (qmi_wds_data_system_network_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DATA_SYSTEM_NETWORK_TYPE_IS_ENUM__

/**
 * qmi_wds_data_system_network_type_get_string:
 * @val: a QmiWdsDataSystemNetworkType.
 *
 * Gets the nickname string for the #QmiWdsDataSystemNetworkType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_data_system_network_type_get_string (QmiWdsDataSystemNetworkType val);
GType qmi_wds_data_system_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DATA_SYSTEM (qmi_wds_data_system_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DATA_SYSTEM_IS_ENUM__

/**
 * qmi_wds_data_system_get_string:
 * @val: a QmiWdsDataSystem.
 *
 * Gets the nickname string for the #QmiWdsDataSystem specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_data_system_get_string (QmiWdsDataSystem val);
GType qmi_wds_pdp_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_PDP_TYPE (qmi_wds_pdp_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_PDP_TYPE_IS_ENUM__

/**
 * qmi_wds_pdp_type_get_string:
 * @val: a QmiWdsPdpType.
 *
 * Gets the nickname string for the #QmiWdsPdpType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_pdp_type_get_string (QmiWdsPdpType val);
GType qmi_wds_traffic_class_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_TRAFFIC_CLASS (qmi_wds_traffic_class_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_TRAFFIC_CLASS_IS_ENUM__

/**
 * qmi_wds_traffic_class_get_string:
 * @val: a QmiWdsTrafficClass.
 *
 * Gets the nickname string for the #QmiWdsTrafficClass specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_traffic_class_get_string (QmiWdsTrafficClass val);
GType qmi_wds_profile_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_PROFILE_TYPE (qmi_wds_profile_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_PROFILE_TYPE_IS_ENUM__

/**
 * qmi_wds_profile_type_get_string:
 * @val: a QmiWdsProfileType.
 *
 * Gets the nickname string for the #QmiWdsProfileType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wds_profile_type_get_string (QmiWdsProfileType val);
GType qmi_wds_profile_family_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_PROFILE_FAMILY (qmi_wds_profile_family_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_PROFILE_FAMILY_IS_ENUM__

/**
 * qmi_wds_profile_family_get_string:
 * @val: a QmiWdsProfileFamily.
 *
 * Gets the nickname string for the #QmiWdsProfileFamily specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.22
 */
const gchar *qmi_wds_profile_family_get_string (QmiWdsProfileFamily val);
GType qmi_wds_delivery_order_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DELIVERY_ORDER (qmi_wds_delivery_order_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DELIVERY_ORDER_IS_ENUM__

/**
 * qmi_wds_delivery_order_get_string:
 * @val: a QmiWdsDeliveryOrder.
 *
 * Gets the nickname string for the #QmiWdsDeliveryOrder specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_delivery_order_get_string (QmiWdsDeliveryOrder val);
GType qmi_wds_sdu_error_ratio_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_SDU_ERROR_RATIO (qmi_wds_sdu_error_ratio_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_SDU_ERROR_RATIO_IS_ENUM__

/**
 * qmi_wds_sdu_error_ratio_get_string:
 * @val: a QmiWdsSduErrorRatio.
 *
 * Gets the nickname string for the #QmiWdsSduErrorRatio specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_sdu_error_ratio_get_string (QmiWdsSduErrorRatio val);
GType qmi_wds_sdu_residual_bit_error_ratio_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_SDU_RESIDUAL_BIT_ERROR_RATIO (qmi_wds_sdu_residual_bit_error_ratio_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_SDU_RESIDUAL_BIT_ERROR_RATIO_IS_ENUM__

/**
 * qmi_wds_sdu_residual_bit_error_ratio_get_string:
 * @val: a QmiWdsSduResidualBitErrorRatio.
 *
 * Gets the nickname string for the #QmiWdsSduResidualBitErrorRatio specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_sdu_residual_bit_error_ratio_get_string (QmiWdsSduResidualBitErrorRatio val);
GType qmi_wds_sdu_erroneous_delivery_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_SDU_ERRONEOUS_DELIVERY (qmi_wds_sdu_erroneous_delivery_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_SDU_ERRONEOUS_DELIVERY_IS_ENUM__

/**
 * qmi_wds_sdu_erroneous_delivery_get_string:
 * @val: a QmiWdsSduErroneousDelivery.
 *
 * Gets the nickname string for the #QmiWdsSduErroneousDelivery specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_sdu_erroneous_delivery_get_string (QmiWdsSduErroneousDelivery val);
GType qmi_wds_ds_profile_error_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DS_PROFILE_ERROR (qmi_wds_ds_profile_error_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DS_PROFILE_ERROR_IS_ENUM__

/**
 * qmi_wds_ds_profile_error_get_string:
 * @val: a QmiWdsDsProfileError.
 *
 * Gets the nickname string for the #QmiWdsDsProfileError specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.8
 */
const gchar *qmi_wds_ds_profile_error_get_string (QmiWdsDsProfileError val);
GType qmi_wds_autoconnect_setting_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_AUTOCONNECT_SETTING (qmi_wds_autoconnect_setting_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_AUTOCONNECT_SETTING_IS_ENUM__

/**
 * qmi_wds_autoconnect_setting_get_string:
 * @val: a QmiWdsAutoconnectSetting.
 *
 * Gets the nickname string for the #QmiWdsAutoconnectSetting specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_autoconnect_setting_get_string (QmiWdsAutoconnectSetting val);
GType qmi_wds_autoconnect_setting_roaming_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_AUTOCONNECT_SETTING_ROAMING (qmi_wds_autoconnect_setting_roaming_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_AUTOCONNECT_SETTING_ROAMING_IS_ENUM__

/**
 * qmi_wds_autoconnect_setting_roaming_get_string:
 * @val: a QmiWdsAutoconnectSettingRoaming.
 *
 * Gets the nickname string for the #QmiWdsAutoconnectSettingRoaming specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.14
 */
const gchar *qmi_wds_autoconnect_setting_roaming_get_string (QmiWdsAutoconnectSettingRoaming val);
GType qmi_wds_dormancy_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DORMANCY_STATUS (qmi_wds_dormancy_status_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DORMANCY_STATUS_IS_ENUM__

/**
 * qmi_wds_dormancy_status_get_string:
 * @val: a QmiWdsDormancyStatus.
 *
 * Gets the nickname string for the #QmiWdsDormancyStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_dormancy_status_get_string (QmiWdsDormancyStatus val);
GType qmi_wds_data_call_status_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DATA_CALL_STATUS (qmi_wds_data_call_status_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DATA_CALL_STATUS_IS_ENUM__

/**
 * qmi_wds_data_call_status_get_string:
 * @val: a QmiWdsDataCallStatus.
 *
 * Gets the nickname string for the #QmiWdsDataCallStatus specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_data_call_status_get_string (QmiWdsDataCallStatus val);
GType qmi_wds_data_call_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_DATA_CALL_TYPE (qmi_wds_data_call_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_DATA_CALL_TYPE_IS_ENUM__

/**
 * qmi_wds_data_call_type_get_string:
 * @val: a QmiWdsDataCallType.
 *
 * Gets the nickname string for the #QmiWdsDataCallType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_data_call_type_get_string (QmiWdsDataCallType val);
GType qmi_wds_tethered_call_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_TETHERED_CALL_TYPE (qmi_wds_tethered_call_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_TETHERED_CALL_TYPE_IS_ENUM__

/**
 * qmi_wds_tethered_call_type_get_string:
 * @val: a QmiWdsTetheredCallType.
 *
 * Gets the nickname string for the #QmiWdsTetheredCallType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_tethered_call_type_get_string (QmiWdsTetheredCallType val);
GType qmi_wds_radio_access_technology_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_RADIO_ACCESS_TECHNOLOGY (qmi_wds_radio_access_technology_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_RADIO_ACCESS_TECHNOLOGY_IS_ENUM__

/**
 * qmi_wds_radio_access_technology_get_string:
 * @val: a QmiWdsRadioAccessTechnology.
 *
 * Gets the nickname string for the #QmiWdsRadioAccessTechnology specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_radio_access_technology_get_string (QmiWdsRadioAccessTechnology val);
GType qmi_wds_pdp_header_compression_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_PDP_HEADER_COMPRESSION_TYPE (qmi_wds_pdp_header_compression_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_PDP_HEADER_COMPRESSION_TYPE_IS_ENUM__

/**
 * qmi_wds_pdp_header_compression_type_get_string:
 * @val: a QmiWdsPdpHeaderCompressionType.
 *
 * Gets the nickname string for the #QmiWdsPdpHeaderCompressionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_pdp_header_compression_type_get_string (QmiWdsPdpHeaderCompressionType val);
GType qmi_wds_pdp_data_compression_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_PDP_DATA_COMPRESSION_TYPE (qmi_wds_pdp_data_compression_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_PDP_DATA_COMPRESSION_TYPE_IS_ENUM__

/**
 * qmi_wds_pdp_data_compression_type_get_string:
 * @val: a QmiWdsPdpDataCompressionType.
 *
 * Gets the nickname string for the #QmiWdsPdpDataCompressionType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_pdp_data_compression_type_get_string (QmiWdsPdpDataCompressionType val);
GType qmi_wds_qos_class_identifier_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_QOS_CLASS_IDENTIFIER (qmi_wds_qos_class_identifier_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_QOS_CLASS_IDENTIFIER_IS_ENUM__

/**
 * qmi_wds_qos_class_identifier_get_string:
 * @val: a QmiWdsQosClassIdentifier.
 *
 * Gets the nickname string for the #QmiWdsQosClassIdentifier specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_qos_class_identifier_get_string (QmiWdsQosClassIdentifier val);
GType qmi_wds_attach_pdn_list_action_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_ATTACH_PDN_LIST_ACTION (qmi_wds_attach_pdn_list_action_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_ATTACH_PDN_LIST_ACTION_IS_ENUM__

/**
 * qmi_wds_attach_pdn_list_action_get_string:
 * @val: a QmiWdsAttachPdnListAction.
 *
 * Gets the nickname string for the #QmiWdsAttachPdnListAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_wds_attach_pdn_list_action_get_string (QmiWdsAttachPdnListAction val);
GType qmi_wds_client_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_CLIENT_TYPE (qmi_wds_client_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_CLIENT_TYPE_IS_ENUM__

/**
 * qmi_wds_client_type_get_string:
 * @val: a QmiWdsClientType.
 *
 * Gets the nickname string for the #QmiWdsClientType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_wds_client_type_get_string (QmiWdsClientType val);
GType qmi_wds_ip_support_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_IP_SUPPORT_TYPE (qmi_wds_ip_support_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_IP_SUPPORT_TYPE_IS_ENUM__

/**
 * qmi_wds_ip_support_type_get_string:
 * @val: a QmiWdsIpSupportType.
 *
 * Gets the nickname string for the #QmiWdsIpSupportType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_wds_ip_support_type_get_string (QmiWdsIpSupportType val);
GType qmi_wds_profile_change_event_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WDS_PROFILE_CHANGE_EVENT (qmi_wds_profile_change_event_get_type ())

/* Define type-specific symbols */
#define __QMI_WDS_PROFILE_CHANGE_EVENT_IS_ENUM__

/**
 * qmi_wds_profile_change_event_get_string:
 * @val: a QmiWdsProfileChangeEvent.
 *
 * Gets the nickname string for the #QmiWdsProfileChangeEvent specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.34
 */
const gchar *qmi_wds_profile_change_event_get_string (QmiWdsProfileChangeEvent val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums-wms.h" */
GType qmi_wms_storage_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_STORAGE_TYPE (qmi_wms_storage_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_STORAGE_TYPE_IS_ENUM__

/**
 * qmi_wms_storage_type_get_string:
 * @val: a QmiWmsStorageType.
 *
 * Gets the nickname string for the #QmiWmsStorageType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_storage_type_get_string (QmiWmsStorageType val);
GType qmi_wms_ack_indicator_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_ACK_INDICATOR (qmi_wms_ack_indicator_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_ACK_INDICATOR_IS_ENUM__

/**
 * qmi_wms_ack_indicator_get_string:
 * @val: a QmiWmsAckIndicator.
 *
 * Gets the nickname string for the #QmiWmsAckIndicator specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_ack_indicator_get_string (QmiWmsAckIndicator val);
GType qmi_wms_message_format_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_FORMAT (qmi_wms_message_format_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_FORMAT_IS_ENUM__

/**
 * qmi_wms_message_format_get_string:
 * @val: a QmiWmsMessageFormat.
 *
 * Gets the nickname string for the #QmiWmsMessageFormat specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_format_get_string (QmiWmsMessageFormat val);
GType qmi_wms_message_mode_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_MODE (qmi_wms_message_mode_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_MODE_IS_ENUM__

/**
 * qmi_wms_message_mode_get_string:
 * @val: a QmiWmsMessageMode.
 *
 * Gets the nickname string for the #QmiWmsMessageMode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_mode_get_string (QmiWmsMessageMode val);
GType qmi_wms_notification_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_NOTIFICATION_TYPE (qmi_wms_notification_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_NOTIFICATION_TYPE_IS_ENUM__

/**
 * qmi_wms_notification_type_get_string:
 * @val: a QmiWmsNotificationType.
 *
 * Gets the nickname string for the #QmiWmsNotificationType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_notification_type_get_string (QmiWmsNotificationType val);
GType qmi_wms_cdma_service_option_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_CDMA_SERVICE_OPTION (qmi_wms_cdma_service_option_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_CDMA_SERVICE_OPTION_IS_ENUM__

/**
 * qmi_wms_cdma_service_option_get_string:
 * @val: a QmiWmsCdmaServiceOption.
 *
 * Gets the nickname string for the #QmiWmsCdmaServiceOption specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_cdma_service_option_get_string (QmiWmsCdmaServiceOption val);
GType qmi_wms_cdma_cause_code_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_CDMA_CAUSE_CODE (qmi_wms_cdma_cause_code_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_CDMA_CAUSE_CODE_IS_ENUM__

/**
 * qmi_wms_cdma_cause_code_get_string:
 * @val: a QmiWmsCdmaCauseCode.
 *
 * Gets the nickname string for the #QmiWmsCdmaCauseCode specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_cdma_cause_code_get_string (QmiWmsCdmaCauseCode val);
GType qmi_wms_cdma_error_class_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_CDMA_ERROR_CLASS (qmi_wms_cdma_error_class_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_CDMA_ERROR_CLASS_IS_ENUM__

/**
 * qmi_wms_cdma_error_class_get_string:
 * @val: a QmiWmsCdmaErrorClass.
 *
 * Gets the nickname string for the #QmiWmsCdmaErrorClass specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_cdma_error_class_get_string (QmiWmsCdmaErrorClass val);
GType qmi_wms_gsm_umts_rp_cause_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_GSM_UMTS_RP_CAUSE (qmi_wms_gsm_umts_rp_cause_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_GSM_UMTS_RP_CAUSE_IS_ENUM__

/**
 * qmi_wms_gsm_umts_rp_cause_get_string:
 * @val: a QmiWmsGsmUmtsRpCause.
 *
 * Gets the nickname string for the #QmiWmsGsmUmtsRpCause specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_gsm_umts_rp_cause_get_string (QmiWmsGsmUmtsRpCause val);
GType qmi_wms_gsm_umts_tp_cause_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_GSM_UMTS_TP_CAUSE (qmi_wms_gsm_umts_tp_cause_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_GSM_UMTS_TP_CAUSE_IS_ENUM__

/**
 * qmi_wms_gsm_umts_tp_cause_get_string:
 * @val: a QmiWmsGsmUmtsTpCause.
 *
 * Gets the nickname string for the #QmiWmsGsmUmtsTpCause specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_gsm_umts_tp_cause_get_string (QmiWmsGsmUmtsTpCause val);
GType qmi_wms_message_delivery_failure_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_DELIVERY_FAILURE_TYPE (qmi_wms_message_delivery_failure_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_DELIVERY_FAILURE_TYPE_IS_ENUM__

/**
 * qmi_wms_message_delivery_failure_type_get_string:
 * @val: a QmiWmsMessageDeliveryFailureType.
 *
 * Gets the nickname string for the #QmiWmsMessageDeliveryFailureType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_delivery_failure_type_get_string (QmiWmsMessageDeliveryFailureType val);
GType qmi_wms_message_tag_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_TAG_TYPE (qmi_wms_message_tag_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_TAG_TYPE_IS_ENUM__

/**
 * qmi_wms_message_tag_type_get_string:
 * @val: a QmiWmsMessageTagType.
 *
 * Gets the nickname string for the #QmiWmsMessageTagType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_tag_type_get_string (QmiWmsMessageTagType val);
GType qmi_wms_message_protocol_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_PROTOCOL (qmi_wms_message_protocol_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_PROTOCOL_IS_ENUM__

/**
 * qmi_wms_message_protocol_get_string:
 * @val: a QmiWmsMessageProtocol.
 *
 * Gets the nickname string for the #QmiWmsMessageProtocol specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_protocol_get_string (QmiWmsMessageProtocol val);
GType qmi_wms_message_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_TYPE (qmi_wms_message_type_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_TYPE_IS_ENUM__

/**
 * qmi_wms_message_type_get_string:
 * @val: a QmiWmsMessageType.
 *
 * Gets the nickname string for the #QmiWmsMessageType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_type_get_string (QmiWmsMessageType val);
GType qmi_wms_message_class_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_MESSAGE_CLASS (qmi_wms_message_class_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_MESSAGE_CLASS_IS_ENUM__

/**
 * qmi_wms_message_class_get_string:
 * @val: a QmiWmsMessageClass.
 *
 * Gets the nickname string for the #QmiWmsMessageClass specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_message_class_get_string (QmiWmsMessageClass val);
GType qmi_wms_receipt_action_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_RECEIPT_ACTION (qmi_wms_receipt_action_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_RECEIPT_ACTION_IS_ENUM__

/**
 * qmi_wms_receipt_action_get_string:
 * @val: a QmiWmsReceiptAction.
 *
 * Gets the nickname string for the #QmiWmsReceiptAction specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_receipt_action_get_string (QmiWmsReceiptAction val);
GType qmi_wms_transfer_indication_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_TRANSFER_INDICATION (qmi_wms_transfer_indication_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_TRANSFER_INDICATION_IS_ENUM__

/**
 * qmi_wms_transfer_indication_get_string:
 * @val: a QmiWmsTransferIndication.
 *
 * Gets the nickname string for the #QmiWmsTransferIndication specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_wms_transfer_indication_get_string (QmiWmsTransferIndication val);
GType qmi_wms_ack_failure_cause_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_WMS_ACK_FAILURE_CAUSE (qmi_wms_ack_failure_cause_get_type ())

/* Define type-specific symbols */
#define __QMI_WMS_ACK_FAILURE_CAUSE_IS_ENUM__

/**
 * qmi_wms_ack_failure_cause_get_string:
 * @val: a QmiWmsAckFailureCause.
 *
 * Gets the nickname string for the #QmiWmsAckFailureCause specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_wms_ack_failure_cause_get_string (QmiWmsAckFailureCause val);

/* enumerations from "../git/src/libqmi-glib/qmi-enums.h" */
GType qmi_service_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_SERVICE (qmi_service_get_type ())

/* Define type-specific symbols */
#define __QMI_SERVICE_IS_ENUM__

/**
 * qmi_service_get_string:
 * @val: a QmiService.
 *
 * Gets the nickname string for the #QmiService specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.0
 */
const gchar *qmi_service_get_string (QmiService val);
GType qmi_endian_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_ENDIAN (qmi_endian_get_type ())

/* Define type-specific symbols */
#define __QMI_ENDIAN_IS_ENUM__

/**
 * qmi_endian_get_string:
 * @val: a QmiEndian.
 *
 * Gets the nickname string for the #QmiEndian specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_endian_get_string (QmiEndian val);
GType qmi_data_endpoint_type_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_DATA_ENDPOINT_TYPE (qmi_data_endpoint_type_get_type ())

/* Define type-specific symbols */
#define __QMI_DATA_ENDPOINT_TYPE_IS_ENUM__

/**
 * qmi_data_endpoint_type_get_string:
 * @val: a QmiDataEndpointType.
 *
 * Gets the nickname string for the #QmiDataEndpointType specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.18
 */
const gchar *qmi_data_endpoint_type_get_string (QmiDataEndpointType val);
GType qmi_sio_port_get_type (void) G_GNUC_CONST;
#define QMI_TYPE_SIO_PORT (qmi_sio_port_get_type ())

/* Define type-specific symbols */
#define __QMI_SIO_PORT_IS_ENUM__

/**
 * qmi_sio_port_get_string:
 * @val: a QmiSioPort.
 *
 * Gets the nickname string for the #QmiSioPort specified at @val.
 *
 * Returns: (transfer none): a string with the nickname, or %NULL if not found. Do not free the returned value.
 * Since: 1.28
 */
const gchar *qmi_sio_port_get_string (QmiSioPort val);
G_END_DECLS

#endif /* __LIBQMI_GLIB_ENUM_TYPES_H__ */

/* Generated data ends here */

